Learn R Programming

apisensr (version 1.0.0)

apisensr-package: Interface to 'episensr' for sensitivity analysis of epidemiological results

Description

API for using 'episensr' which provides basic sensitivity analysis of the observed relative risks adjusting for unmeasured confounding and misclassification of the exposure/outcome, or both.

Arguments

Author

Maintainer: Denis Haine denis.haine@gmail.com (ORCID)

References

'episensr' on R CRAN https://cran.r-project.org/package=episensr

See Also

Examples

Run this code
if (FALSE) {
run_app()
}

Run the code above in your browser using DataLab